import streamlit as st


class GameState:
    def __init__(self, width, height):
        self.width = width
        self.height = height
        self.grid = [
            ['_' for col in range(width)]
            for row in range(height)]
        self.turn = 0
        
    def draw(self):
        st_cols = st.columns(self.width)
        for col_idx in range(self.width):
            with st_cols[col_idx]:
                for row_idx in range(self.height):
                    contents = self.grid[row_idx][col_idx]
                    st.button(contents,
                              key=f"button_{row_idx},{col_idx}",
                              on_click=self.on_button_click,
                              args = (row_idx, col_idx))

    def on_button_click(self, row, col):
        cur_player = ['x', 'y'][self.turn]
        # Note: for a game like Connect 4, we would
        # ignore the row and just drop the piece in
        # the given column.
        self.grid[row][col] = cur_player
        self.turn = (self.turn + 1) % 2
        # We don't need to call self.draw() because
        # the button click will cause the script to
        # re-run from the top, so the `game.draw()` 
        # call at the bottom of the script will be
        # executed.


def get_game(reset=False):
    if reset or 'game' not in st.session_state:
        # make a new game
        game = GameState(7, 6)
        # Store it in the session state for later.
        st.session_state['game'] = game
    return st.session_state['game']


game = get_game()
game.draw()
#st.write(game.grid)


st.button("Reset", on_click=get_game, kwargs={'reset': True})
